---
name: "gdcmscanner"
section: "1"
platform: "linux"
package: "libgdcm-tools"
version: "3.0.24-5+b3"
release: "Debian 13 (Trixie)"
platforms: ["linux"]
url: "https://new.carta.tech/gdcmscanner"
---

# gdcmscanner(1)

Scan a directory containing DICOM files.

## NAME

gdcmscanner - Scan a directory containing DICOM files.

## SYNOPSIS

```
gdcmscanner [options] directory
```

## DESCRIPTION

The **gdcmscanner** is a command line tool to quickly extract value from a set of DICOM attribute in a DICOM File-Set.

### PARAMETERS

```
  -d --dir       DICOM directory
  -t --tag %d,%d DICOM tag(s) to look for
  -k --keyword %s           DICOM keyword(s) to look for
  -P --private-tag %d,%d,%s DICOM private tag(s) to look for
```

### OPTIONS

```
  -p --print      Print output.
  -r --recursive  Recursively descend directory.
     --strict     Use strict parser (faster but less tolerant with bogus DICOM files).
     --table      Use Table output.
```

### general options

```
  -h   --help
         print this help text and exit
  -v   --version
         print version information and exit
  -V   --verbose
         verbose mode (warning+error).
  -W   --warning
         warning mode, print warning information
  -E   --error
         error mode, print error information
  -D   --debug
         debug mode, print debug information
```

## TYPICAL USAGE

## SIMPLE USAGE

In order to display all the value for Patient Name (0010,0010) in the directory name **gdcmData**, simply do:

```
$ gdcmscanner -t 10,10 -d gdcmData -p
```

For private tag simply do:

```
$ gdcmscanner -P "0029,60,SIEMENS MEDCOM HEADER2" -d gdcmData -p
```

## TABLE USAGE

In order to display as CSV (see dicom3tools/dctable) all the values for SOP Instance / Study Instance / Series Instance UID(s) in the directory name **gdcmData**, simply do:

```
$ gdcmscanner -k SOPInstanceUID -k StudyInstanceUID -k SeriesInstanceUID -d gdcmData -p --table
```

## COMPLEX USAGE

Because gdcmscanner does not support progress, you have to wait until all files are traversed to see any results. This is quite cumbersome, on UNIX this can be worked around with the following trick:

```
$ find gdcmData -type d -exec gdcmscanner -t 10,10 -d {} -p ';'
```

So all directory are locally traversed (no child directory are recursively traversed), which means results comes out much faster.

## SEE ALSO

[**dctable**(1)](/dctable/1.md), [**gdcmdump**(1)](/gdcmdump/1.md), [**gdcmraw**(1)](/gdcmraw/1.md)

## AUTHOR

**Mathieu Malaterre**

Main developer

## COPYRIGHT

Copyright © 2006, 2011 Mathieu Malaterre\
